@@ -13,12 +13,12 @@ class UnixConfig(Config):
 
     def _load(self):
         default_config_path = (
-            pathlib.Path('/etc') / f'{self.__app_name}.d' / self.__config_name
+            pathlib.Path('/etc') / f'{self._app_name}.d' / self._config_name
         )
         data = {}
 
         if default_config_path.exists():
             with open(default_config_path, 'r') as fp:
-                data.update(self.__SERIALIZER.loads(fp.read()))
-        data.update(super().__load())
+                data.update(self._SERIALIZER.loads(fp.read()))
+        data.update(super()._load())
         return data
