@@ -1,3 +1,7 @@
+'''
+Mixins for xdgconfig.config.Config objects.
+'''
+
 import contextlib
 
 from xdgconfig.serializers import ini, json
@@ -9,10 +13,16 @@ __all__ = [
 
 
 class JsonMixin:
+    '''
+    Mixin to use a JSON serializer.
+    '''
     _SERIALIZER = json
 
 
 class IniMixin:
+    '''
+    Mixin to use an INI serializer.
+    '''
     _SERIALIZER = ini
 
 
@@ -21,6 +31,9 @@ with contextlib.suppress(ImportError):
     __all__.append('XmlMixin')
 
     class XmlMixin:
+        '''
+        Mixin to use an XML serializer.
+        '''
         _SERIALIZER = xml
 
 
@@ -29,6 +42,9 @@ with contextlib.suppress(ImportError):
     __all__.append('TomlMixin')
 
     class TomlMixin:
+        '''
+        Mixin to use a TOML serializer.
+        '''
         _SERIALIZER = toml
 
 
@@ -37,4 +53,7 @@ with contextlib.suppress(ImportError):
     __all__.append('YamlMixin')
 
     class YamlMixin:
+        '''
+        Mixin to use a YAML serializer.
+        '''
         _SERIALIZER = yaml
